@@ -1,6 +1,6 @@
 package App::colsummary ;  
-our $VERSION = '0.055' ; 
-our $DATE = '2021-06-11T00:08+09:00' ; 
+our $VERSION = '0.056' ; 
+our $DATE = '2021-06-11T01:18+09:00' ; 
 
 =encoding utf8
 
@@ -34,7 +34,7 @@ $0
        (入力オプション)
       -=     ; 入力の最初の行が列名の並びと仮定。この指定をしない場合は列名は連番になる。
       -i STR : 区切り文字をタブ文字ではなくて、 str  に変更。
-      -v 10  ; 各セルの値の長さを指定文字数に制限する。(列名には適用されない。)
+      -v N   ; 各セルの値の長さを指定文字数に制限する。(列名には適用されない。)
       -s     ; 各セルの末尾の空白を除去。-uがあると半角空白だけで無くて全角空白も除去。
       -u     ; utf-8 として処理することとする。 -u が指定されないと、バイト単位の処理となる。
       -z     ; 入力は gzip 圧縮されていることを仮定。
